@@ -31,7 +31,6 @@ import numpy as np
 from IPython import get_ipython
 from IPython import version_info as ipython_version_info
 from IPython.display import HTML, display
-from ipython_genutils.py3compat import string_types
 from ipywidgets import DOMWidget, widget_serialization
 from matplotlib import is_interactive, rcParams
 from matplotlib._pylab_helpers import Gcf
@@ -248,7 +247,7 @@ class Canvas(DOMWidget, FigureCanvasWebAggCore):
     def send_state(self, key=None):
         if key is None:
             keys = self.keys
-        elif isinstance(key, string_types):
+        elif isinstance(key, str):
             keys = [key]
         elif isinstance(key, Iterable):
             keys = key
@@ -385,74 +384,9 @@ class Canvas(DOMWidget, FigureCanvasWebAggCore):
         data = self._repr_mimebundle_(**kwargs)
         display(data, raw=True)
 
-    if matplotlib.__version__ < '3.4':
-        # backport the Python side changes to match the js changes
-        def _handle_key(self, event):
-            _SPECIAL_KEYS_LUT = {
-                'Alt': 'alt',
-                'AltGraph': 'alt',
-                'CapsLock': 'caps_lock',
-                'Control': 'control',
-                'Meta': 'meta',
-                'NumLock': 'num_lock',
-                'ScrollLock': 'scroll_lock',
-                'Shift': 'shift',
-                'Super': 'super',
-                'Enter': 'enter',
-                'Tab': 'tab',
-                'ArrowDown': 'down',
-                'ArrowLeft': 'left',
-                'ArrowRight': 'right',
-                'ArrowUp': 'up',
-                'End': 'end',
-                'Home': 'home',
-                'PageDown': 'pagedown',
-                'PageUp': 'pageup',
-                'Backspace': 'backspace',
-                'Delete': 'delete',
-                'Insert': 'insert',
-                'Escape': 'escape',
-                'Pause': 'pause',
-                'Select': 'select',
-                'Dead': 'dead',
-                'F1': 'f1',
-                'F2': 'f2',
-                'F3': 'f3',
-                'F4': 'f4',
-                'F5': 'f5',
-                'F6': 'f6',
-                'F7': 'f7',
-                'F8': 'f8',
-                'F9': 'f9',
-                'F10': 'f10',
-                'F11': 'f11',
-                'F12': 'f12',
-            }
-
-            def handle_key(key):
-                """Handle key values"""
-                value = key[key.index('k') + 1 :]
-                if 'shift+' in key:
-                    if len(value) == 1:
-                        key = key.replace('shift+', '')
-                if value in _SPECIAL_KEYS_LUT:
-                    value = _SPECIAL_KEYS_LUT[value]
-                key = key[: key.index('k')] + value
-                return key
-
-            key = handle_key(event['key'])
-            e_type = event['type']
-            guiEvent = event.get('guiEvent', None)
-            if e_type == 'key_press':
-                self.key_press_event(key, guiEvent=guiEvent)
-            elif e_type == 'key_release':
-                self.key_release_event(key, guiEvent=guiEvent)
-
-        handle_key_press = handle_key_release = _handle_key
-
 
 class FigureManager(FigureManagerWebAgg):
-    if matplotlib.__version__ < "3.6":
+    if matplotlib.__version_info__ < (3, 6):
         ToolbarCls = Toolbar
 
     def __init__(self, canvas, num):
